@@ -20,9 +20,9 @@
 """Holds state that is shared among many modules.
 """
 
-__id__        = "$Id: orca_state.py 2371 2007-05-11 15:28:14Z richb $"
-__version__   = "$Revision: 2371 $"
-__date__      = "$Date: 2007-05-11 11:28:14 -0400 (Fri, 11 May 2007) $"
+__id__        = "$Id: orca_state.py 3384 2007-12-16 17:14:06Z joanied $"
+__version__   = "$Revision: 3384 $"
+__date__      = "$Date: 2007-12-16 12:14:06 -0500 (Sun, 16 Dec 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -30,6 +30,10 @@ __license__   = "LGPL"
 # easily cause circular imports.
 #
 
+# History of focused accessibles, helps caching.
+#
+focusHistory = []
+
 # The Accessible that has visual focus.
 #
 locusOfFocus = None
@@ -82,3 +86,42 @@ lastWord = ""
 #
 searchQuery = None
 
+# Whether we should use the pronunciation dictionary to help speak 
+# certain words. This will be True everywhere except when focus is 
+# in the Pronunciation Dictionary in the Orca Preferences dialog.
+#
+usePronunciationDictionary = True
+
+# Handle to the Orca Preferences Glade GUI object.
+#
+orcaOS = None
+
+# Handle to the Orca application specific preferences Glade GUI object.
+#
+appOS = None
+
+# Handle to the Glade warning dialog object that is displayed, if the 
+# user has attempted to start a second instance of a preferences dialog.
+#
+orcaWD = None
+
+# Handle to the Orca Preferences Glade file.
+#
+prefsGladeFile = None
+
+# Handles to the magnification Advanced Settings Glade GUI object and dialog.
+#
+advancedMag = None
+advancedMagDialog = None
+
+# Whether magnification "color enhancements" are currently enabled.
+#
+colorEnhancementsEnabled = True
+
+# Whether magnification "mouse enhancements" are currently enabled.
+#
+mouseEnhancementsEnabled = True
+
+# The current zoomer type.
+#
+zoomerType = None
