@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 3387 2007-12-17 16:34:14Z joanied $"
-__version__   = "$Revision: 3387 $"
-__date__      = "$Date: 2007-12-17 11:34:14 -0500 (Mon, 17 Dec 2007) $"
+__id__        = "$Id: settings.py 3445 2008-01-11 17:05:52Z wwalker $"
+__version__   = "$Revision: 3445 $"
+__date__      = "$Date: 2008-01-11 12:05:52 -0500 (Fri, 11 Jan 2008) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -259,7 +259,11 @@ httpServerPort          = 20433
 # The number of attempts to retry setting up an HTTP server
 # connection (each time incrementing the port number by 1).
 #
-maxHttpServerRetries   = 20
+maxHttpServerRetries    = 20
+
+# Whether or not recording is enabled via the HTTP server. 
+#
+enableRemoteLogging     = False
 
 # If True, enable speech.
 #
